<?php
/************************************************************************
 * MXChange v0.2.1                                    Start: 10/08/2005 *
 * ===============                              Last change: 01/01/2006 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : gen_sql_patches.php                              *
 * -------------------------------------------------------------------- *
 * Short description : Patch password system after upgrading            *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Patcht das Passwort-System nach DB-Update        *
 * -------------------------------------------------------------------- *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2008 by Roland Haeder                           *
 * For more information visit: http://www.mxchange.org                  *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	$INC = substr(dirname(__FILE__), 0, strpos(dirname(__FILE__), "/inc") + 4) . "/security.php";
	require($INC);
}

// Check for version of sql_patches
if (EXT_VERSION_IS_OLDER("sql_patches", "0.3.6")) return false;

// Check if there is no scrambling string
if (empty($_CONFIG['pass_scramble'])) {
	// Generate 40 chars long scramble string
	$scrambleString = genScrambleString(40);

	// ... and store it there for future usage
	UPDATE_CONFIG("pass_scramble", $scrambleString);

	// Also remember it in config
	$_CONFIG['pass_scramble'] = $scrambleString;
	unset($scrambleString);
}

// Check if there is no master salt string
if (empty($_CONFIG['master_salt'])) {
	// Generate the master salt which is the first chars minus 40 chars of this random hash
	// We do an extra scrambling here...
	$masterSalt = scrambleString(substr(generateHash(GEN_PASS(rand(128, 256))), 0, -40));

	// ... and store it there for future usage
	UPDATE_CONFIG("master_salt", $masterSalt);

	// Also remember it in config
	$_CONFIG['master_salt'] = $masterSalt;
	unset($masterSalt);
}

if (empty($_CONFIG['file_hash'])) {
	// Create filename from hashed random string
	$file_hash = generateHash(GEN_PASS(rand(128, 256)));
	$file = sprintf("%sinc/.secret/.%s", PATH, $file_hash);

	// File hash was never created
	$fp = @fopen($file, 'w') or mxchange_die("Cannot write secret key file!");
	if ($fp != false) {
		// Could write to secret file! So let's generate the secret key...
		// 1. Count of chars to be taken from back of the string
		$nums = rand(40, 45);
		// 2. Generate secret key from a randomized string
		$secretKey = substr(generateHash(GEN_PASS(rand(128, 256))), -$nums);
		// 3. Write the key to the file
		fwrite($fp, $secretKey);
		// 4. Close file
		fclose($fp);

		// Change access rights for more security
		@chmod($file, 0644);

		//* DEBUG: */ unlink($file);
		//* DEBUG: */ $test = hexdec(get_session('u_hash')) / hexdec($secretKey);
		//* DEBUG: */ $test = generateHash(str_replace('.', "", $test));
		//* DEBUG: */ die("Secret-Key: ".$secretKey."<br />Cookie: ".get_session('u_hash')."<br />Test: ".$test);

		// Write $file_hash to database
		UPDATE_CONFIG("file_hash", $file_hash);

		// Also update configuration
		$_CONFIG['secret_key'] = $secretKey;
		$_CONFIG['file_hash']  = $file_hash;

		// And remove some variables
		unset($secretKey);
		unset($file_hash);
	}
}

//
?>
